EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_GetLatestEnvironmentExecutions',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Applications_LatestEnvironmentExecutions',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets a view of all the latest executions grouped by application and environment, optionally filtered by application or application group.'
GO


IF OBJECT_ID('[Applications_GetLatestEnvironmentExecutions]') IS NOT NULL DROP PROCEDURE [Applications_GetLatestEnvironmentExecutions]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_GetLatestEnvironmentExecutions]
(
	@Application_Id INT = NULL,
    @ApplicationGroup_Id INT = NULL
)
AS
BEGIN

	SELECT *
	  FROM [Applications_LatestEnvironmentExecutions] ALEE

	 WHERE (@Application_Id IS NULL OR [Application_Id] = @Application_Id)
       AND (@ApplicationGroup_Id IS NULL OR EXISTS(SELECT * 
                                                     FROM [ApplicationGroups] AG
                                              CROSS APPLY dbo.ApplicationGroups_GetAncestorGroups(AG.[ApplicationGroup_Id]) AGA
                                                    WHERE AGA.[ApplicationGroup_Id] = @ApplicationGroup_Id
                                                      AND AG.[ApplicationGroup_Id] = ALEE.[ApplicationGroup_Id])
            )
	 ORDER BY   
	          CASE WHEN ALEE.[ApplicationGroup_Id] IS NULL THEN 1 ELSE 0 END
	         ,[ApplicationGroup_Name]
	         ,[Application_Name]

END
GO

GRANT EXECUTE ON [Applications_GetLatestEnvironmentExecutions] TO [BuildMasterUser_Role]
