EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_CompletePromotion',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Completes a build promotion.'
GO


IF OBJECT_ID('[Builds_CompletePromotion]') IS NOT NULL DROP PROCEDURE [Builds_CompletePromotion]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_CompletePromotion]
(
	@Promotion_Id INT,
	@PromotionStatus_Name VARCHAR(20),
	@StatusOverriddenReason_Text VARCHAR(100)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [BuildPromotions]
	   SET [PromotionStatus_Name] = @PromotionStatus_Name,
	       [StatusOverridden_Date] = CASE WHEN @StatusOverriddenReason_Text IS NOT NULL THEN GETUTCDATE() ELSE NULL END,
		   [StatusOverriddenBy_User_Name] = CASE WHEN @StatusOverriddenReason_Text IS NOT NULL THEN dbo.Session_GetUserName() ELSE NULL END,
		   [StatusOverriddenReason_Text] = @StatusOverriddenReason_Text
	 WHERE [Promotion_Id] = @Promotion_Id

     DECLARE @Application_Id INT
     DECLARE @Release_Number RELEASENUMBER
     DECLARE @Build_Number BUILDNUMBER
     DECLARE @PipelineStage_Name VARCHAR(50)

     SELECT @Application_Id = R.[Application_Id],
            @Release_Number = R.[Release_Number],
            @Build_Number = B.[Build_Number],
            @PipelineStage_Name = P.[PipelineStage_Name]
       FROM [BuildPromotions] P
      INNER JOIN [Builds] B ON P.[Build_Id] = B.[Build_Id]
      LEFT JOIN [Releases] R ON B.[Release_Id] = R.[Release_Id]
      WHERE P.[Promotion_Id] = @Promotion_Id

	IF @Release_Number IS NOT NULL
		EXEC [Events_RaiseEvent] 'BLDCPP', @Application_Id, @Release_Number, @Build_Number, @PipelineStage_Name
	ELSE
		EXEC [Events_RaiseEvent] 'BLDCPP', @Application_Id, '', @Build_Number, @PipelineStage_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Builds_CompletePromotion] TO [BuildMasterUser_Role]