EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_CreateConfigurationFileInstance',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new instance of a configuration file.',
	/* Remarks_Text            */ 'If an instance with the specified name already exists but has been deactivated, the old instance will be reactivated and a blank version will be inserted as the latest.'
GO

IF OBJECT_ID('[ConfigurationFiles_CreateConfigurationFileInstance]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_CreateConfigurationFileInstance]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_CreateConfigurationFileInstance]
(
	@ConfigurationFile_Id INT,
	@Instance_Name VARCHAR(100),
	@Environment_Id INT,
	@Template_Indicator YNINDICATOR,
	@Template_Instance_Name VARCHAR(100),
	@TransformType_Code CHAR(1),
	@EditorType_Code CHAR(1)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF NOT EXISTS(SELECT *
                    FROM [ConfigurationFileInstances]
					WITH (UPDLOCK)
				   WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
				     AND [Instance_Name] = @Instance_Name)
	BEGIN

		INSERT INTO [ConfigurationFileInstances]
        (
			[ConfigurationFile_Id],
			[Instance_Name],
			[Environment_Id],
			[Active_Indicator],
			[Template_Indicator],
			[Template_Instance_Name],
			[TransformType_Code],
			[EditorType_Code]
		)
	    VALUES
	    (
			@ConfigurationFile_Id,
			@Instance_Name,
			@Environment_Id,
			'Y',
			@Template_Indicator,
			@Template_Instance_Name,
			@TransformType_Code,
			@EditorType_Code
		)

	END
	ELSE IF (SELECT [Active_Indicator]
	           FROM [ConfigurationFileInstances]
			   WITH (UPDLOCK)
			  WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
			    AND [Instance_Name] = @Instance_Name) = 'N'
	BEGIN

		UPDATE [ConfigurationFileInstances]
		   SET [Active_Indicator] = 'Y',
		       [Environment_Id] = @Environment_Id,
			   [Template_Indicator] = @Template_Indicator,
			   [Template_Instance_Name] = @Template_Instance_Name,
			   [TransformType_Code] = @TransformType_Code,
			   [EditorType_Code] = @EditorType_Code
		 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
		   AND [Instance_Name] = @Instance_Name

	END
	ELSE
		RAISERROR('Configuration file instance already exists.', 16, 1)

	-- If there are any versions at all
	IF EXISTS(SELECT *
	            FROM [ConfigurationFileVersions]
				WITH (UPDLOCK)
			   WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id)
	BEGIN

		-- Find latest version with actual data
		DECLARE @Latest_NonNull_Version INT
		SET @Latest_NonNull_Version = (SELECT MAX([Version_Number])
		                                 FROM [ConfigurationFileVersions]
										WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
										  AND [Instance_Name] = @Instance_Name
										  AND [Null_Indicator] = 'N')

		-- If there isn't a latest version
		IF @Latest_NonNull_Version IS NULL
		-- or there is, but it is not empty
		OR (SELECT DATALENGTH([File_Bytes])
		      FROM [ConfigurationFileVersions]
			 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
			   AND [Instance_Name] = @Instance_Name
			   AND [Version_Number] = @Latest_NonNull_Version) <> 0
		BEGIN

			DECLARE @Rubbish INT
			SET @Rubbish = COALESCE((SELECT MAX([Version_Number])
				                       FROM [ConfigurationFileVersions]
				                      WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
				                        AND [Instance_Name] = @Instance_Name), 0) + 1

			-- Insert a blank version as the latest for this instance
			INSERT INTO [ConfigurationFileVersions]
			(
				[ConfigurationFile_Id],
				[Instance_Name],
				[Version_Number],
				[VersionNotes_Text],
				[File_Date],
				[File_Bytes],
				[CreatedBy_User_Name],
				[CreatedOn_Date]
			)
			VALUES
			(
				@ConfigurationFile_Id,
				@Instance_Name,
				@Rubbish,
				NULL,
				GETUTCDATE(),
				0x,
				dbo.Session_GetUserName(),
				GETUTCDATE()
			)

			-- Make sure there are no gaps
			EXEC [ConfigurationFiles_FillVersionGaps] @ConfigurationFile_Id

		END

	END


	DECLARE @Application_Id INT
	 SELECT @Application_Id = [Application_Id]
	   FROM [ConfigurationFiles]
	  WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	EXEC [Events_RaiseEvent] 'CFGNWI', @Application_Id, @ConfigurationFile_Id, @Instance_Name
		
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_CreateConfigurationFileInstance] TO [BuildMasterUser_Role]
