EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CreatePipelineStageDeploymentExecution',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Execution_Id',
    /* Description_Text        */ 'Creates a pipeline stage deployment execution.'
GO

IF OBJECT_ID('[Executions_CreatePipelineStageDeploymentExecution]') IS NOT NULL DROP PROCEDURE [Executions_CreatePipelineStageDeploymentExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CreatePipelineStageDeploymentExecution]
(
	@Promotion_Id INT,
	@Start_Date DATETIME,
	@Variables_Table dbo.DeploymentVariableEntry READONLY,
	@Execution_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [Executions]
	(
		[Start_Date],
		[ExecutionStatus_Code],
		[ExecutionRunState_Code],
		[ExecutionMode_Code],
		[CreatedBy_User_Name],
		[CreatedOn_Date]
	)
	VALUES
	(
		COALESCE(@Start_Date, GETUTCDATE()),
		'S',
		'P',
		'S',
		dbo.Session_GetUserName(),
		GETUTCDATE()
	)

	SET @Execution_Id = SCOPE_IDENTITY()

	INSERT INTO [PipelineStageDeploymentExecutions]
	(
		[Execution_Id],
		[Promotion_Id]
	)
	VALUES
	(
		@Execution_Id,
		@Promotion_Id
	)

	INSERT INTO [DeploymentVariables]
	SELECT [Execution_Id] = @Execution_Id,
	       [Variable_Name],
		   [ValueType_Code],
		   [Variable_Value],
		   [Sensitive_Indicator],
		   [EvaluateVariables_Indicator]
	  FROM @Variables_Table

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH
END
GO

GRANT EXECUTE ON [Executions_CreatePipelineStageDeploymentExecution] TO [BuildMasterUser_Role]
