EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RetentionPolicies_CreateOrUpdateRetentionPolicy',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'RetentionPolicy_Id',
    /* Description_Text        */ 'Creates or updates a retention policy.'
GO

IF OBJECT_ID('[RetentionPolicies_CreateOrUpdateRetentionPolicy]') IS NOT NULL DROP PROCEDURE [RetentionPolicies_CreateOrUpdateRetentionPolicy]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RetentionPolicies_CreateOrUpdateRetentionPolicy]
(
	@RetentionPolicy_Name NVARCHAR(50),
	@PurgeType_Code CHAR(1),
	@PurgeIn_Application_Id INT,
	@PurgeIn_ApplicationGroup_Id INT,
	@PurgeIn_OnlyDeployedReleases_Indicator YNINDICATOR,
	@PurgeIn_OnlyRejectedBuilds_Indicator YNINDICATOR,
    @PurgeOrphanedArtifacts_Indicator YNINDICATOR,
	@PurgeIn_Pipeline_Name VARCHAR(100),
	@PurgeIn_Environment_Id INT,
	@Retention_Count INT,
	@Retention_Size BIGINT,
    @Retention_Days_Count INT,
	@PurgeWindow_Start_Minutes INT,
    @PurgeWindow_Duration_Minutes INT,
    @Active_Indicator YNINDICATOR,
	@RetentionPolicy_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [RetentionPolicies]
			    WITH (UPDLOCK)
			   WHERE [RetentionPolicy_Id] = @RetentionPolicy_Id)
	BEGIN

		UPDATE [RetentionPolicies]
		   SET [RetentionPolicy_Name] = NULLIF(RTRIM(LTRIM(@RetentionPolicy_Name)), ''),
		       [PurgeType_Code] = @PurgeType_Code,
			   [PurgeIn_Application_Id] = @PurgeIn_Application_Id,
			   [PurgeIn_ApplicationGroup_Id] = @PurgeIn_ApplicationGroup_Id,
			   [PurgeIn_OnlyDeployedReleases_Indicator] = @PurgeIn_OnlyDeployedReleases_Indicator,
			   [PurgeIn_OnlyRejectedBuilds_Indicator] = @PurgeIn_OnlyRejectedBuilds_Indicator,
               [PurgeOrphanedArtifacts_Indicator] = @PurgeOrphanedArtifacts_Indicator,
			   [PurgeIn_Pipeline_Name] = @PurgeIn_Pipeline_Name,
			   [PurgeIn_Environment_Id] = @PurgeIn_Environment_Id,
			   [Retention_Count] = @Retention_Count,
			   [Retention_Size] = @Retention_Size,
               [Retention_Days_Count] = @Retention_Days_Count,
			   [PurgeWindow_Start_Minutes] = @PurgeWindow_Start_Minutes,
               [PurgeWindow_Duration_Minutes] = @PurgeWindow_Duration_Minutes,
               [Active_Indicator] = @Active_Indicator,
			   [ModifiedOn_Date] = GETUTCDATE(),
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName()
		 WHERE [RetentionPolicy_Id] = @RetentionPolicy_Id

	END
	ELSE
	BEGIN

		INSERT INTO [RetentionPolicies]
		(
			[RetentionPolicy_Name],
			[PurgeType_Code],
			[PurgeIn_Application_Id],
			[PurgeIn_ApplicationGroup_Id],
			[PurgeIn_OnlyDeployedReleases_Indicator],
			[PurgeIn_OnlyRejectedBuilds_Indicator],
            [PurgeOrphanedArtifacts_Indicator],
			[PurgeIn_Pipeline_Name],
			[PurgeIn_Environment_Id],
			[Retention_Count],
			[Retention_Size],
            [Retention_Days_Count],
			[PurgeWindow_Start_Minutes],
            [PurgeWindow_Duration_Minutes],
            [Active_Indicator],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@RetentionPolicy_Name,
			@PurgeType_Code,
			@PurgeIn_Application_Id,
			@PurgeIn_ApplicationGroup_Id,
			@PurgeIn_OnlyDeployedReleases_Indicator,
			@PurgeIn_OnlyRejectedBuilds_Indicator,
            @PurgeOrphanedArtifacts_Indicator,
			@PurgeIn_Pipeline_Name,
			@PurgeIn_Environment_Id,
			@Retention_Count,
			@Retention_Size,
            @Retention_Days_Count,
			@PurgeWindow_Start_Minutes,
            @PurgeWindow_Duration_Minutes,
            @Active_Indicator,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)

		SET @RetentionPolicy_Id = SCOPE_IDENTITY()

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RetentionPolicies_CreateOrUpdateRetentionPolicy] TO [BuildMasterUser_Role]