EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Users_DeleteGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a user group from the system, but does not delete the users who belong to the group'
GO

IF OBJECT_ID('[dbo].[Users_DeleteGroup]') IS NOT NULL
	DROP PROCEDURE [dbo].[Users_DeleteGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[Users_DeleteGroup]
(
	@Group_Name VARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	/* Remove group privileges */
	DELETE [Privileges]
	 WHERE [Principal_Name] = @Group_Name
	   AND [PrincipalType_Code] = 'G'

	/* Remove group users */
	DELETE [UserGroups]
	 WHERE [Group_Name] = @Group_Name

	/* Remove group */
	DELETE [Groups]
	 WHERE [Group_Name] = @Group_Name

	EXEC [Events_RaiseEvent] 'USRDLG', NULL, @Group_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [dbo].[Users_DeleteGroup] TO [BuildMasterUser_Role]
GO
